# 🪵 Changelog

## [0.0.4](https://github.com/vemonet/openroute-mcp/compare/v0.0.3..v0.0.4) - 2026-01-31

### ⛰️ Features

- HTML route returned as MCP app - ([8c8f358](https://github.com/vemonet/openroute-mcp/commit/8c8f3580ea54c0f8b78217d7baf2bc9c8c6ba75f))

### 📚 Documentation

- Improve MCP `server.json` config - ([ab5e957](https://github.com/vemonet/openroute-mcp/commit/ab5e957017dc0ce90a4c1817179fd42a090c81a7))

## [0.0.3](https://github.com/vemonet/openroute-mcp/compare/v0.0.2..v0.0.3) - 2025-10-10

### ⛰️ Features

- Add official mcp registry `server.json` config file - ([025f3c6](https://github.com/vemonet/openroute-mcp/commit/025f3c6664a3e43a67434caa8998785632a227e5))

### 🛠️ Miscellaneous Tasks

- Improve MCP registry `server.json` - ([2e7d2ab](https://github.com/vemonet/openroute-mcp/commit/2e7d2abb4e6a7896420acfcc8d5c92e584d56a83))

## [0.0.2](https://github.com/vemonet/openroute-mcp/compare/v0.0.1..v0.0.2) - 2025-10-08

### ⛰️ Features

- Enable configuration through CLI arguments, improve `Dockerfile` - ([944e63c](https://github.com/vemonet/openroute-mcp/commit/944e63ce3c6b885f0d559ea5951575aa8e447574))
- Add `--debug` flag to enable more debugging logs, fix API key check - ([8d7b52b](https://github.com/vemonet/openroute-mcp/commit/8d7b52b3e613bab537d89493a6b7464a9088a24b))

### 🐛 Bug Fixes

- Fix docker host - ([d17ae86](https://github.com/vemonet/openroute-mcp/commit/d17ae8620582ee835da50cebb8fccc055c0bb73d))

## [0.0.1](https://github.com/vemonet/openroute-mcp/tree/v0.0.1) - 2025-10-08

### ⛰️ Features

- Initial commit - ([bd92846](https://github.com/vemonet/openroute-mcp/commit/bd92846aa6c804a2ddbc5003d1643bc169b312da))
- Add `search_pois` tool - ([56532d6](https://github.com/vemonet/openroute-mcp/commit/56532d68f226d141e9285f194a7e8a926f7713df))
- Properly generate and return as resource a PNG image of the route, and a HTML file to visualize the route with openstreetmap - ([a7848cc](https://github.com/vemonet/openroute-mcp/commit/a7848cccbb10d16495ad7a9bd45f13c7299cf4af))
- Add `get_coordinates_object` and `get_reachable_area` tools - ([267fded](https://github.com/vemonet/openroute-mcp/commit/267fded7265acffdbcaf1a0bd5e33157def761f8))

### 📚 Documentation

- Update readme - ([e65be2b](https://github.com/vemonet/openroute-mcp/commit/e65be2b07189f1d0f1d387e7075d9777fc88e142))

<!-- generated by git-cliff -->
